@@ -2,23 +2,12 @@ import argparse
 import logging
 from pathlib import Path
 
-from appdirs import user_config_dir, user_data_dir
-
 from .ui import ModlunkyUI
-from .config import Config
-
-APP_AUTHOR = "spelunky.fyi"
-APP_NAME = "modlunky2"
+from .config import Config, make_user_dirs
 
 logger = logging.getLogger("modlunky2")
 
 
-def make_dirs(*dirs):
-    for dir_ in dirs:
-        if not dir_.exists():
-            dir_.mkdir(parents=True, exist_ok=True)
-
-
 def main():
     parser = argparse.ArgumentParser(description="Tool for modding Spelunky 2.")
     parser.add_argument(
@@ -40,18 +29,15 @@ def main():
 
     log_format = "%(asctime)s: %(message)s"
     log_level = logging.getLevelName(args.log_level)
-
     logging.basicConfig(format=log_format, level=logging.INFO, datefmt="%H:%M:%S")
     logger.setLevel(log_level)
     launch(args, log_level)
 
 
 def launch(args, log_level):
-    config_dir = Path(user_config_dir(APP_NAME, APP_AUTHOR))
-    data_dir = Path(user_data_dir(APP_NAME, APP_AUTHOR))
 
-    make_dirs(config_dir, data_dir)
-    config = Config.from_path(config_dir / "config.json")
+    make_user_dirs()
+    config = Config.default()
 
     if args.install_dir:
         config.install_dir = Path(args.install_dir)
